package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````H"-```````!``````````+#$````
M`````````$``.``(`$``'0`<``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````$QC````````3&,`````````
M`"````````$````&````4&,```````!08V```````%!C8```````-&``````
M``#P<```````````(````````@````8```!X8P```````'AC8```````>&-@
M``````#P`0```````/`!````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%#E=&0$
M````,%T````````P74```````#!=0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@```!H````$````%`````,```!'
M3E4`4!@G)$K2ZCF+7B@R\]W<V@ECJJ%A````9P````````````````````4`
M`````````````#4`````````'0```"D````>`````````#X````)````50``
M```````4````1P```$@````E````60```&0````&````/P``````````````
M`P```%L````\``````````````!,````4P```$\````X`````````&8```!+
M````/0```"\`````````-@````````!0`````````$8````W````````````
M``!?````.@```!,````;``````````````!2````)@```#$````J````````
M```````(`````````"@``````````````$(``````````0```"0````*````
M00```%<```!B``````````````!<````3@```"L```!8````0````#,````P
M`````````%T```````````````````!>````30`````````L````5````#(`
M```+````5@````(`````````````````````````````````````````````
M``0```````````````````!@````````````````````````````````````
M````````````````%0````````!E```````````````'````%@``````````
M``````````````!C`````````!(````9````0P```!$```!A````&````%H`
M```G````1``````````B`````````!<````N````'P``````````````````
M````````````2@`````````````````````````[```````````````Y````
M20```#0`````````````````````````````````````````#P```!H````,
M````````````````````'````"`````A`````````",``````````````"T`
M```0````#0``````````````40``````````````````````````````#@``
M````````````10``````````````$0```$,````$````"````"`<$``%0`2&
M*@)``)"&`:A"*``@22`$"[BB.$VZ!`8*0P```$0```!(````30```$X```!5
M````5P```%D```!<````7@````````!@````8P```&0```!E````````````
M``![\$IK;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.?$&.Q;B-\0[59-1\V7%8
M'.)'Q@&L2^/`\MO3';KCDGS"Y3\L^J%L8+,!BV]J"4/6A_F<@6:OS&;%N9Q`
M0D75[,2)!9`Y\HL<#!3BGLG5LG':S>.>,V+;[0PZEPM6I)N6I]VC:W^IG)OA
MIP(*"HH05Z/@^TD`````````````````````````````````````!P$``!(`
M``````````````````````````(``!(`````````````````````````CP(`
M`!(`````````````````````````=@(``!(`````````````````````````
M7`(``!(`````````````````````````E@(``!(`````````````````````
M````%`,``!(`````````````````````````G0```!(`````````````````
M````````JP(``!(`````````````````````````[@(``!(`````````````
M````````````Y@(``!(`````````````````````````>0```!(`````````
M````````````````R`,``!(``````````````````````````@$``!(`````
M````````````````````S@(``!(`````````````````````````N0(``!(`
M````````````````````````?@(``!(`````````````````````````#0,`
M`!(`````````````````````````)`,``!(`````````````````````````
M:P$``!(`````````````````````````*P$``!(`````````````````````
M````P`(``!(`````````````````````````JP```!(`````````````````
M````````M0$``!(`````````````````````````+0(``!(`````````````
M````````````;0(``!(`````````````````````````4@$``!(`````````
M````````````````/0(``!(`````````````````````````9`(``!(`````
M````````````````````H@$``!(`````````````````````````I`(``!(`
M````````````````````````^P$``!(`````````````````````````4P,`
M`!(`````````````````````````U`(``!(`````````````````````````
M3`,``!(`````````````````````````.0$``!(`````````````````````
M````*P,``!(`````````````````````````$0```"``````````````````
M````````0@```!(`````````````````````````V0```!(`````````````
M````````````&0(``!(`````````````````````````K@$``!(`````````
M````````````````B````!(`````````````````````````8`$``!(`````
M````````````````````-````!(`````````````````````````#`$``!(`
M````````````````````````EP$``!(`````````````````````````Y@``
M`!(`````````````````````````G`(``!(`````````````````````````
M]`$``!(`````````````````````````/0,``!(`````````````````````
M````,P,``!(`````````````````````````>0$``!(`````````````````
M````````10,``!(`````````````````````````L@(``!(`````````````
M````````````(````"``````````````````````````O0```!(`````````
M````````````````'0,``!(`````````````````````````20$``!(`````
M````````````````````VP(``!(`````````````````````````5`(``!(`
M````````````````````````3P(``!(`````````````````````````$0(`
M`!(`````````````````````````40```!(`````````````````````````
MQP(``!(`````````````````````````^`(``!(`````````````````````
M````AP$``!(```#P'4``````````````````T0,``!(`#@`@6$```````'``
M````````GP,``!(`#P#(64``````````````````]@,``!(`#@"P24``````
M`'T*````````8`,``!(`#@"0(4````````X"````````I0,``!(`#@"00T``
M``````4`````````6@0``!(`#@"@0T```````*@!````````AP0``!(`#@"0
M6$```````#H`````````5`0``!(`#``X'4``````````````````HP0``!(`
M#@`P5$```````.<#````````A`,``!``\?^$PV``````````````````W0,`
M`!(`#@!014```````"4`````````$`0``!$`$`#864````````0`````````
MP`$``!$`&@#`PV```````!,`````````D`,``!``\?]`U&``````````````
M````4@0``!(`#@!@0D```````"H`````````9P0``!(`#@"@2$````````D!
M````````>00``!(`#@`@2$```````$@``````````P0``!``&0"@9V``````
M````````````:````!(```#`($``````````````````Z@,``!(`#@"`14``
M`````,X`````````90,``!$`&@"PPV````````@`````````?0,``!``\?^$
MPV``````````````````9@,``"$`&@"PPV````````@`````````!@,``!$`
M&@#8PV````````@`````````E0,``!(`#@#P6$````````(`````````&`$`
M`!(````@($``````````````````-00``!(`#@``64```````(D`````````
M"00``!(`#@"@(T``````````````````!00``"``&0"@9V``````````````
M````]P```!$`&@"@PV````````0`````````9P,``"$`&@"PPV````````@`
M````````M@,``!(`#@!P2$```````"0`````````'P0``!(`#@#@0D``````
M`*H`````````S````!$`&@"HPV````````$`````````100``!(`#@!01D``
M`````,L!`````````&QI8G!E<FPN<V\N-2XQ-`!?7V=M;VY?<W1A<G1?7P!?
M2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW
M:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV
M`&QI8G!T:')E860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)C+G-O+C8`
M7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC;7``7U]S=')D
M=7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US
M970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X
M<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<W1R8VAR`&9P<FEN=&8`<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S
M`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N
M<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`
M<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP
M9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`'!A<E]I;FET7V5N=@!X<U]I;FET
M`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#
M7S(N-``````"``,``@`"``(``@`"`````@`"``(````"`````@`"``0``@`"
M```````"```````#``(````%``(````"``,``@`"``(````"``````````,`
M`@`````````````````"``,``@`"`````@`"```````"`````@`"``(``P``
M``(`!@````$``0`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!````
M`0`"``$``@`"``$````!``$``0````(``0`!`````0```````0`!`.0!```0
M````(````'4::0D```,`N00````````!``0`,P(``!``````````$VEI#0``
M!@#%!```$````'(9:0D```4`SP0``!`````4:6D-```$`-L$```0````=1II
M"0```@"Y!````````&AE8```````!@```"8``````````````*##8```````
M!0```&$``````````````*C#8```````!0```&4``````````````+##8```
M````!0```%@``````````````,##8```````!0```%```````````````-C#
M8```````!0```%L``````````````(AE8```````!P````$`````````````
M`)!E8```````!P````(``````````````)AE8```````!P````,`````````
M`````*!E8```````!P````0``````````````*AE8```````!P````4`````
M`````````+!E8```````!P````8``````````````+AE8```````!P````<`
M`````````````,!E8```````!P````@``````````````,AE8```````!P``
M``D``````````````-!E8```````!P```$,``````````````-AE8```````
M!P````H``````````````.!E8```````!P````L``````````````.AE8```
M````!P````P``````````````/!E8```````!P````T``````````````/AE
M8```````!P````X```````````````!F8```````!P````\`````````````
M``AF8```````!P```!```````````````!!F8```````!P```!$`````````
M`````!AF8```````!P```!(``````````````"!F8```````!P```!,`````
M`````````"AF8```````!P```!0``````````````#!F8```````!P```!4`
M`````````````#AF8```````!P```!8``````````````$!F8```````!P``
M`!<``````````````$AF8```````!P```!@``````````````%!F8```````
M!P```!D``````````````%AF8```````!P```!H``````````````&!F8```
M````!P```!L``````````````&AF8```````!P```!P``````````````'!F
M8```````!P```!T``````````````'AF8```````!P```!X`````````````
M`(!F8```````!P```!\``````````````(AF8```````!P```"``````````
M`````)!F8```````!P```"$``````````````)AF8```````!P```"(`````
M`````````*!F8```````!P```",``````````````*AF8```````!P```"0`
M`````````````+!F8```````!P```"4``````````````+AF8```````!P``
M`"<``````````````,!F8```````!P```"@``````````````,AF8```````
M!P```"D``````````````-!F8```````!P```"H``````````````-AF8```
M````!P```"L``````````````.!F8```````!P```"P``````````````.AF
M8```````!P```%T``````````````/!F8```````!P```"T`````````````
M`/AF8```````!P```"X```````````````!G8```````!P```"\`````````
M``````AG8```````!P```#```````````````!!G8```````!P```#$`````
M`````````!AG8```````!P```#(``````````````"!G8```````!P```#,`
M`````````````"AG8```````!P```#0``````````````#!G8```````!P``
M`#4``````````````#AG8```````!P```%8``````````````$!G8```````
M!P```#8``````````````$AG8```````!P```#<``````````````%!G8```
M````!P```#D``````````````%AG8```````!P```#H``````````````&!G
M8```````!P```#L``````````````&AG8```````!P```#P`````````````
M`'!G8```````!P```#T``````````````'AG8```````!P```#X`````````
M`````(!G8```````!P```#\``````````````(AG8```````!P```$``````
M`````````)!G8```````!P```$$``````````````)AG8```````!P```$(`
M`````````````$B#[`CHBP8``.@:!P``Z$4\``!(@\0(P_\U(D@@`/\E)$@@
M``\?0`#_)2)((`!H`````.G@_____R4:2"``:`$```#IT/____\E$D@@`&@"
M````Z<#_____)0I((`!H`P```.FP_____R4"2"``:`0```#IH/____\E^D<@
M`&@%````Z9#_____)?)'(`!H!@```.F`_____R7J1R``:`<```#I</____\E
MXD<@`&@(````Z6#_____)=I'(`!H"0```.E0_____R721R``:`H```#I0/__
M__\ERD<@`&@+````Z3#_____)<)'(`!H#````.D@_____R6Z1R``:`T```#I
M$/____\ELD<@`&@.````Z0#_____):I'(`!H#P```.GP_O___R6B1R``:!``
M``#IX/[___\EFD<@`&@1````Z=#^____)9)'(`!H$@```.G`_O___R6*1R``
M:!,```#IL/[___\E@D<@`&@4````Z:#^____)7I'(`!H%0```.F0_O___R5R
M1R``:!8```#I@/[___\E:D<@`&@7````Z7#^____)6)'(`!H&````.E@_O__
M_R5:1R``:!D```#I4/[___\E4D<@`&@:````Z4#^____)4I'(`!H&P```.DP
M_O___R5"1R``:!P```#I(/[___\E.D<@`&@=````Z1#^____)3)'(`!H'@``
M`.D`_O___R4J1R``:!\```#I\/W___\E(D<@`&@@````Z>#]____)1I'(`!H
M(0```.G0_?___R421R``:"(```#IP/W___\E"D<@`&@C````Z;#]____)0)'
M(`!H)````.F@_?___R7Z1B``:"4```#ID/W___\E\D8@`&@F````Z8#]____
M)>I&(`!H)P```.EP_?___R7B1B``:"@```#I8/W___\EVD8@`&@I````Z5#]
M____)=)&(`!H*@```.E`_?___R7*1B``:"L```#I,/W___\EPD8@`&@L````
MZ2#]____);I&(`!H+0```.D0_?___R6R1B``:"X```#I`/W___\EJD8@`&@O
M````Z?#\____):)&(`!H,````.G@_/___R6:1B``:#$```#IT/S___\EDD8@
M`&@R````Z<#\____)8I&(`!H,P```.FP_/___R6"1B``:#0```#IH/S___\E
M>D8@`&@U````Z9#\____)7)&(`!H-@```.F`_/___R5J1B``:#<```#I</S_
M__\E8D8@`&@X````Z6#\____)5I&(`!H.0```.E0_/___R521B``:#H```#I
M0/S___\E2D8@`&@[````Z3#\____)4)&(`!H/````.D@_/___R4Z1B``:#T`
M``#I$/S___\E,D8@`&@^````Z0#\____)2I&(`!H/P```.GP^____R4B1B``
M:$````#IX/O___\E&D8@`&A!````Z=#[____)1)&(`!H0@```.G`^___4TB#
M["")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D".@)_O__NB`@0`"_P"!`
M`$B)UN@'-P``@#W8H2```'4OZ`G]__](A<!(B057LB``#X2<`0``2(G'Z#'\
M__^+/:NA(`#HYOW__\:`S`0```"+/9FA(`#HU/W__X"(.P4```*+/8>A(`#H
MPOW__XM\)!R`B#L%```!@\<%2&/_2(7_#X@3`0``\D@/*L?R#U@%VSH``&8/
M+@7;.@``#X<Z`0``2,'G`^CD_/__2(M\)!!(B06XL2``QP6VL2``!````$B+
M%TC'0`C!6T``2,=`$.!G8`!(QT`8Q%M``$B)$(M4)!R#^@%^*HU*_DR-!,T(
M````,<EF+@\?A```````2(MT#PA(B70(($B#P0A,.<%U[8U*!$B+/6NQ(`"#
MP@-%,<"^D$)``$ACR4C'1,CX`````$B)P>AD_?__A<")PW0V2(L]/[$@`.BB
M^___,<"_A5I``.@6&```2(7`="E(BSTBL2``Z"7[___H$/W__TB#Q"")V%O#
M2(L]";$@`.C<_?__B</KNDB+/?&P(`!(A?]T).C7-```Z\1(B?A(B?I(T>B#
MX@%("=#R2`\JP/(/6,#IU?[__[\Z6D``Z*X7``!(A<!(B<=(B06QL"``=([K
MP;\!````Z+/]__^^P,-@`+\U6D``,<#H8OS__Y"0,>U)B=%>2(GB2(/D\%!4
M2<?`\%A``$C'P0!90`!(Q\>0(4``Z*?[___TD)!(@^P(2(L%D4$@`$B%P'0"
M_]!(@\0(PY"0D)"0D)"0D)"0D)!52(GE4TB#[`B`/>"?(```=4N[:&-@`$B+
M!=J?(`!(@>M@8V``2,'[`TB#ZP%(.=AS)&8/'T0``$B#P`%(B06UGR``_Q3%
M8&-@`$B+!:>?(`!(.=ARXL8%DY\@``%(@\0(6UW#9F9F+@\?A```````2(,]
M"#\@``!52(GE=!*X`````$B%P'0(7;]P8V``_^!=PY"0D)"0D)"0D)"0D)"0
M05=,C4<X,<E!5D%505154TB![`@"``!F#Q^$``````!)BQ0(2(G02(G62,'@
M"$C!YAB#YO\E``#_`$@)\$B)UDC![@B!Y@#_``!("?!(B=9(P>X8@>;_````
M2`GP2(G62,'N($B)1$R(2(GP2,'F&$C!X`B#YO\E``#_`$@)\$B)UDC!ZCA(
MP>XH@>8`_P``2`GP2`G02(E$3)!(@\$(2(/Y0`^%=____TB-5"2(2(VT)/`!
M``!(@\)H9@\?1```2(M"V$@S`D@S0JA(,T*82(G!2`'`2,'I'T@)P8/A_TB)
M2AA(@\((2#GR==1,BP=(BU\@3(M/"$R+5Q!,BU\82(G:3(G`2`-4)(A,B<%(
MP>@;2,'A!4R)WD@#="202`G(3(G!@^#_2/?12(VL`IEY@EI,B<A,B=)(]]!,
M(<I,(=%,(=A("=!,B<H!Q4R)R$C!XAY(P>@"28GM2`G0@^#_2(G"3"'"2`G*
M2(GI3(VD%IEY@EI(B>I(P>$%2,'J&TR)UD@#="282`G*3(G!00'43(G"2,'I
M`DC!XAY("=%(B>J#X?](]]))(<U((<),">I-B>5(C;06F7F"6DR)XDG!Y05(
MP>H;3`GJ38GE`=9(B>I(P>H"2,'E'D@#1"2@2`GJ3(GE@^+_2/?522'52"'-
M2`-,)*A,">U)B?5(C:PHF7F"6DB)\$G!Y05(P>@;3`GH28GU`<5,B>!)P>0>
M2,'H`DP)X$F)](/@_TGWU$DAQ4DAU$@#5"2P30GL28GM3HVD(9EY@EI(B>E)
MP>4%2,'I&TP)Z4F)[4$!S$B)\4C!YAY(P>D"2`GQ2(GN@^'_2/?622'-2"'&
M3`GN38GE2(VT,IEY@EI,B>)(P>H;2<'E!4@#1"2X3`GJ38GE`=9(B>I(P>4>
M2,'J`D@)ZDR)Y8/B_TCWU4DAU4@AS4@#3"3`3`GM28GU2(VL*)EY@EI(B?!)
MP>4%2,'H&TP)Z$F)]0'%3(G@2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)(=1(
M`U0DR$T)[$F)[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)B>U!`<Q(B?%(P>8>
M2,'I`D@)\4B)[H/A_TCWUD@AQDDAS4@#1"303`GN38GE2(VT,IEY@EI,B>))
MP>4%2,'J&TP)ZDV)Y0'62(GJ2,'E'DC!Z@)(">I,B>6#XO](]]5)(=5((<U(
M`TPDV$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A)B?4!Q4R)X$G!Y!Y(
MP>@"3`G@28GT@^#_2??422'%22'430GL28GM3HVD(9EY@EI(B>E)P>4%2,'I
M&TP)Z4F)[4$!S$B)\4C!YAY(P>D"2`GQ2(GN@^'_2`-4).!(]]9)(<U((<9(
M`T0DZ$P)[DV)Y4G!Y05(C;0RF7F"6DR)XDC!ZAM,">I-B>4!UDB)ZDC!Y1Y(
MP>H"2`GJ3(GE@^+_2/?522'52"'-2`-,)/!,">U)B?5(C:PHF7F"6DB)\$G!
MY05(P>@;3`GH28GU`<5,B>!)P>0>2,'H`DP)X$F)](/@_TGWU$DAQ4DAU$T)
M[$F)[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)B>U!`<Q(B?%(P>D"2,'F'D@#
M5"3X2`GQ2(GN@^'_2/?622'-2"'&2`,$)$P)[DV)Y4B-M#*9>8):3(GB2<'E
M!4C!ZAM,">I-B>4!UDB)ZDC!Y1Y(P>H"2`GJ3(GE@^+_2/?522'52"'-2`-,
M)`A,">U)B?5(C:PHF7F"6DB)\$G!Y05(P>@;3`GH28GU`<5,B>!)P>0>2,'H
M`DP)X$F)](/@_TGWU$DAQ4DAU$T)[$F)[4Z-I"&9>8):2(GI2,'I&TG!Y05(
M`U0D$$P)Z4F)[4$!S$B)\4C!YAY(P>D"2`GQ2(GN@^'_2/?622'-2"'&2`-$
M)!A,">Y-B>5(C;0RF7F"6DR)XDG!Y05(P>H;3`GJ38GE`=9(B>I(P>4>2,'J
M`D@)ZDR)Y8/B_TCWU4DAU4@AS4@#3"0@3`GM28GU2(VL*)EY@EI(B?!)P>4%
M2,'H&TP)Z$F)]0'%3(G@2<'D'DC!Z`),">!)B?2#X/])]]1)(=1)(<5(`U0D
M*$T)[$Z-K"&9>8):2(GI28GL2<'D!4C!Z1M,">%!`<U(B?%(P>8>2,'I`D@)
M\8/A_TB)SD@QQD@#1"0P2#'N3(VD,J'KV6Y,B>I,B>Y(P>8%2,'J&T@)\D$!
MU$B)ZDC!Y1Y(P>H"2`GJ@^+_2(G62#'.2`-,)#A,,>Y(C:PPH>O9;DR)X$R)
MYDC!Y@5(P>@;2`GP`<5,B>A)P>4>2,'H`DP)Z$F)[8/@_TB)QD@QUDG!Y05(
M`U0D0$PQYDB-M#&AZ]EN2(GI2,'I&TP)Z0'.3(GA2<'D'DC!Z0))B?5,">%)
MP>4%@^'_28G,23'$2`-$)$A),>Q.C:0BH>O9;DB)\DC!ZAM,">I!`=1(B>I(
MP>4>2,'J`DV)Y4@)ZDG!Y06#XO](B=5(,<U(`TPD4$@Q]4B-K"BAZ]EN3(G@
M2,'H&TP)Z`'%2(GP2,'F'DC!Z`))B>U("?"#X/](B<9(,=9)P>4%2`-4)%A,
M,>9(C;0QH>O9;DB)Z4C!Z1M,">D!SDR)X4G!Y!Y(P>D"28GU3`GA2<'E!8/A
M_TF)S$DQQ$@#1"1@23'L3HVD(J'KV6Y(B?)(P>H;3`GJ00'42(GJ2,'E'DC!
MZ@)-B>5(">I)P>4%@^+_2(G52#'-2`-,)&A(,?5(C:PHH>O9;DR)X$C!Z!M,
M">@!Q4B)\$C!YAY(P>@"28GM2`GP@^#_2(G&2#'62<'E!4@#5"1P3#'F2(VT
M,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)P>0>2,'I`DF)]4P)X4G!Y06#X?])B<Q)
M,<1(`T0D>$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD$!U$B)ZDC!Y1Y(P>H"38GE
M2`GJ2<'E!8/B_TB)U4@QS4@#C"2`````2#'U2(VL**'KV6Y,B>!(P>@;3`GH
M`<5(B?!(P>8>2,'H`DF)[4@)\(/@_TB)QD@QUDG!Y05(`Y0DB````$PQYDB-
MM#&AZ]EN2(GI2,'I&TP)Z0'.3(GA2<'D'DC!Z0))B?5,">%)P>4%@^'_28G,
M23'$2`.$))````!),>Q.C:0BH>O9;DB)\DC!ZAM,">I!`=1(B>I(P>4>2,'J
M`DV)Y4@)ZDG!Y06#XO](B=5(,<U(`XPDF````$@Q]4B-K"BAZ]EN3(G@2,'H
M&TP)Z`'%2(GP2,'F'DC!Z`))B>U("?"#X/](B<9(,=9)P>4%2`.4)*````!,
M,>9(C;0QH>O9;DB)Z4C!Z1M,">D!SDR)X4G!Y!Y(P>D"28GU3`GA2<'E!8/A
M_TF)S$DQQ$@#A"2H````23'L3HVD(J'KV6Y(B?)(P>H;3`GJ00'42(GJ2,'E
M'DC!Z@)-B>5(">I)P>4%@^+_2(G52#'-2`.,)+````!(,?5(C:PHH>O9;DR)
MX$C!Z!M,">@!Q4B)\$C!YAY(P>@"2`GP@^#_2(G&2#'62`.4)+@```!,,>9,
MC:PQH>O9;DB)Z4B)[DC!Y@5(P>D;2`GQ3(GF2<'D'DC![@)!`<U,">:#YO](
MB?%(,<%(`X0DP````$@QZ4R-I`JAZ]EN3(GJ3(GI2,'A!4C!ZAM("<I(B>E(
MP>4>2,'I`D$!U$@)Z8/A_TB)RD@Q\DPQZDB-K!"AZ]EN3(G@3(GB2,'B!4C!
MZ!M("=!,B>I)P>4>`<5(P>H"N-R\&X],">I)B<5,`ZPDR````(/B_TF)UDP!
M[DF)U4DASDD)S4TAY4T)]4F)[DD!]4B)[DG!Y@5(P>X;3`GV00'U3(GF2<'D
M'DC![@),">9)B<1,`Z0DT````(/F_TF)]DDAUDP!X4F)]$D)U$DA[$T)]$V)
M[DD!S$R)Z4G!Y@5(P>D;3`GQ00',2(GI2,'E'DC!Z0)(">E(B<5(`ZPDV```
M`(/A_TF)SD@!ZDB)S4@)]4PA[4DA]DP)]4V)YD@!U4R)XDG!Y@5(P>H;3`GR
M`=5,B>I)P>4>2,'J`DP)ZDF)Q4P#K"3@````@^+_28G622'.3`'N28G520G-
M32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9!`?5,B>9)P>0>2,'N`DP)YDF)
MQ$P#I"3H````@^;_28GV22'63`'A28GT20G422'L30GT38GN20',3(GI2,'I
M&TG!Y@5,"?%!`<Q(B>E(P>4>2,'I`D@)Z4B)Q4@#K"3P````@^'_28G.22'V
M2`'J2(G-2`GU3"'M3`GU38GF2`'53(GB2<'F!4C!ZAM,"?(!U4R)ZDG!Y1Y(
MP>H"3`GJ28G%3`.L)/@```"#XO])B=9)(<Y,`>Y)B=5)"<U-(>5-"?5)B>Y)
M`?5(B>Y)P>8%2,'N&TP)]D$!]4R)YDG!Y!Y(P>X"3`GF28G$3`.D)``!``"#
MYO])B?9)(=9,`>%)B?1)"=1)(>Q-"?1-B>Y)`<Q,B>E)P>8%2,'I&TP)\4$!
MS$B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)`@!``"#X?])B<Y)(?9(`>I(B<U("?5,
M(>U,"?5-B>9(`=5,B>))P>8%2,'J&TP)\@'53(GJ2<'E'DC!Z@),">I)B<5,
M`ZPD$`$``(/B_TF)UDDASDP![DF)U4D)S4TAY4T)]4F)[DD!]4B)[DG!Y@5(
MP>X;3`GV00'U3(GF2<'D'DC![@),">9)B<1,`Z0D&`$``(/F_TF)]DDAUDP!
MX4F)]$D)U$DA[$T)]$V)[DD!S$R)Z4G!Y@5(P>D;3`GQ00',2(GI2,'E'DC!
MZ0)(">E(B<5(`ZPD(`$``(/A_TF)SD@!ZDB)S4DA]D@)]4PA[4P)]4V)YD@!
MU4R)XDG!Y@5(P>H;3`GR`=5,B>I)P>4>2,'J`DP)ZDF)Q4P#K"0H`0``@^+_
M28G622'.3`'N28G520G-32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9!`?5,
MB>9)P>0>2,'N`DP)YDF)Q$P#I"0P`0``@^;_28GV3`'A28GT20G422'L22'6
M30GT38GN20',3(GI2<'F!4C!Z1M,"?%!`<Q(B>E(P>4>2,'I`D@)Z4B)Q4@#
MK"0X`0``@^'_28G.22'V2`'J2(G-2`GU3"'M3`GU38GF2`'53(GB2<'F!4C!
MZAM,"?(!U4R)ZDG!Y1Y(P>H"3`GJ28G%3`.L)$`!``"#XO])B=9)(<Y,`>Y)
MB=5)"<U-(>5-"?5)B>Y)`?5(B>Y(P>X;2<'F!4P)]D$!]4R)YDG!Y!Y(P>X"
M3`GF28G$3`.D)$@!``"#YO])B?9)(=9,`>%)B?1)"=1)(>Q-"?1-B>Y)`<Q,
MB>E)P>8%2,'I&TP)\4$!S$B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)%`!``"#X?])
MB<Y)(?9(`>I(B<U("?5,(>U,"?5-B>9(`=5,B>))P>8%2,'J&TP)\@'53(GJ
M2<'E'DC!Z@),">I)B<5,`ZPD6`$``(/B_T@#A"1@`0``28G622'.3`'N28G5
M20G-2`'!32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9!`?5,B>9)P>0>2,'N
M`DP)YH/F_TB)\$F)]$@)T$DAU$@AZ$P)X$F)[$C!Y1Y,C30!3(GH3(GI2,'A
M!4C!Z!M)P>P"2`G(20GL00'&N-;!8LI!@^3_2(G!2`.,)&@!``!,B?5(P>4%
M2`'*3(GA2#'Q3#'I2`'13(GR2,'J&T@)ZDR)[4G!Y1Y$C3P*2(G"2`.4)'`!
M``!(P>T"3`GM3(GY@^7_2,'A!4@!UDB)ZDPQXDPQ\DR-+!9,B?I(P>H;2`G*
M3(GQ2<'F'D$!U4B)PD@#E"1X`0``2,'I`DR)[DP)\4C!Y@6#X?])`=1(B<I(
M,>I,,?I)`=1,B>I(P>H;2`GR2(G&00'42`.T)(`!``!,B?I(P>H"2<'G'DV)
MYDP)^DG!Y@6#XO](`?5(B=9(,<Y,,>Y(`?5,B>9(P>X;3`GV`?5,B>Y)P>4>
M2,'N`DF)[DP)[DF)Q4P#K"2(`0``@^;_2<'F!4P!Z4F)]4DQU4TQY4D!S4B)
MZ4C!Z1M,"?%!`<U,B>%)P>0>2,'I`DV)[DP)X4F)Q$P#I"20`0``@^'_3`'B
M28G,23'T2<'F!4DQ[$D!U$R)ZDC!ZAM,"?)!`=1(B>I(P>4>2,'J`DV)YD@)
MZDB)Q4@#K"28`0``@^+_2<'F!4@![DB)U4@QS4PQ[4@!]4R)YDC![AM,"?8!
M]4R)[DG!Y1Y(P>X"28GN3`GN28G%3`.L)*`!``"#YO])P>8%3`'I28GU23'5
M33'E20'-2(GI2,'I&TP)\4$!S4R)X4C!Z0))P>0>38GN3`GA28G$3`.D)*@!
M``"#X?])P>8%3`'B28G,23'T23'L20'43(GJ2,'J&TP)\D$!U$B)ZDC!Y1Y(
MP>H"38GF2`GJ2(G%2`.L)+`!``"#XO])P>8%2`'N2(G52#'-3#'M2`'U3(GF
M2,'N&TP)]@'U3(GN2<'E'DC![@))B>Y,">Y)B<5,`ZPDN`$``(/F_TP!Z4F)
M]4DQU4TQY4G!Y@5)`<U(B>E(P>D;3`GQ00'-3(GA2<'D'DC!Z0)-B>Y,">%)
MB<1,`Z0DP`$``(/A_TG!Y@5,`>))B<Q),?1),>Q)`=1,B>I(P>H;3`GR00'4
M2(GJ2,'E'DC!Z@)-B>9(">I(B<5(`ZPDR`$``(/B_TG!Y@5(`>Y(B=5(,<U,
M,>U(`?5,B>9(P>X;3`GV`?5,B>Y(P>X"2<'E'DF)[DP)[DF)Q4P#K"30`0``
M@^;_2<'F!4P!Z4F)]4DQU4TQY4D!S4B)Z4C!Z1M,"?%!`<U,B>%)P>0>2,'I
M`DV)[DP)X4F)Q$P#I"38`0``@^'_2<'F!4P!XDF)S$DQ]$DQ[$D!U$R)ZDC!
MZAM,"?)!`=1(B>I(P>4>2,'J`DV)YD@)ZDB)Q4@#K"3@`0``@^+_2`'N2(G5
M2#'-3#'M2`'U3(GF2<'F!4C![AM,"?8!]4R)[DG!Y1Y(P>X"28GN3`GN28G%
M3`.L).@!``"#YO])P>8%3`'I28GU23'533'E20'-2(GI2,'I&TP)\4$!S4R)
MX4G!Y!Y(P>D"38GN3`GA28G$3`.D)/`!``"#X?])P>8%3`'B28G,23'T23'L
M20'43(GJ2,'J&TP)\D$!U$B)ZDC!Y1Y(P>H"38GF2`GJ2(G%2`.L)/@!``"#
MXO])P>8%2`.$)``"``!(`>Y(B=5(,<U(`<%,,>U(`?5,B>9(P>X;3`GV1(TT
M+DR)[DG!Y1Y(P>X"3(GE3`GN38GE2,'M`H/F_TG!Y1Y%`?%(B?!,">U$`=Y(
M,=!!`>H!VDPQX$V)]$@!P4R)\$G!Y`5(P>@;3`G@`<A!`<!,B0=,B4\(3(E7
M$$B)=QA(B5<@2('$"`(``%M=05Q!74%>05_#9@\?1```05=)B?=!5D%528G]
M05154TB#[`A(A?]T;4R+-4")(`!-A?9T80^V!SP]='2$P'1P28G\28/$`4$/
MM@0D/#UT!(3`=>]%*>Q)BQXQP$B%VW0W36/D3(GU9@\?A```````3(GB3(GN
M2(G?Z.+B__^%P'4'0H`\(SUT+TB#Q0A(BUT`2(7;==HQP$B#Q`A;74%<05U!
M7D%?PV8/'X0``````$4QY.NB#Q\`3"GU2HU$(P%(P?T#08DO2(/$"%M=05Q!
M74%>05_#9BX/'X0``````$B#[!@QP$B-="0,Z"#___](@\08PV9F+@\?A```
M````4TB)^TB#[!`/'X0``````$B-="0,,<!(B=_H\?[__TB%P'0N2&-$)`Q(
MBQ5`B"``2(T$PDB+4`A(A=)(B1!TT$B#P`A(BU`(2(722(D0=?#KODB#Q!!;
MPP\?A```````55-(@^P(BSWTAR``Z"_D__^+/>F'(`!(BX!@`@``2(MH".@9
MY/__BSW3AR``#[:8Q`0``.@'Y/__2(M`"(/C?P^W0"#!X`<)V&:)10*+/:V'
M(`#HZ./__XL]HH<@`$B+@&`"``!(BU@(Z-+C__\QTKZ[6T``2(G'Z+/C__^+
M/7V'(`!(B4,HZ+3C__^+/6Z'(`!(BX!@`@``2(M8".B>X___2(N`@`8``(L]
M48<@`$B)0S#HB./__XL]0H<@`$B+@&`"``!(BU@(Z'+C__\QTDB#N/@)````
M=!F+/2"'(`#H6^/__TB+@/@)``!(BY"H````BST'AR``2(E3..@^X___2(N`
M8`(``(L]\88@`$B+0`A(QT!``````.@@X___2(N`8`(``(L]TX8@`$B+0`A(
MQT`@`````.@"X___BSV\AB``2(N`8`(``$B+6`CH[.+__TB+@'`"``!(B4-(
M2(/$"%M=PV8N#Q^$``````!(B6PDX$B)7"382(G]3(ED).A,B6PD\$R)="3X
M2('LN````$B%_W0%@#\`=3-(BYPDD````$B+K"28````3(ND)*````!,BZPD
MJ````$R+M"2P````2('$N````,,/'P#HF^#__TB%P$B)PW3`#Q\`2(G?Z!CC
M__](A<!)B<0/A)P```!!@'PD$RX/A*@```!-C6PD$TB)[^BSX/__3(GO28G&
MZ*C@__]%C70&`DEC_N@KXO__3(GI28G$2(G'2(GJOMQ90``QP.A3X___OP$`
M``!(B>),B>;H$^#__X/X_TR)YW00BT0D&"4`\```/0!```!T<^AVW___3(GG
MZ$[?__](B=_HAN+__TB%P$F)Q`^%;O___V8N#Q^$``````!(B=_HR.#__TB)
M[^@0X/__Z?C^__\/'P!!@'PD%``/A"S___]!@'PD%"X/A4#___]!@'PD%0`/
MA!3____I+____P\?@`````#HD_[__P\?`.N(9F9F9F8N#Q^$``````!(B5PD
M\$B);"3X2(G[2(/L&(L]^80@`#'MZ#+A__](C9"8````2(G>OP$```#H7N+_
M_X7`=!J)Z$B+7"0(2(ML)!!(@\08PV8/'X0``````(L]NH0@`.CUX/__BX"P
M````)0#P```]`$```'0=BSV=A"``Z-C@__^+@+`````E`/```#T`H```=:R^
M`@```$B)WS'MZ*?A__^%P$`/E,7KE69F9F9F9BX/'X0``````$%7,<!!5D%5
M05152(G]4TB)\TB#["B`/CT/E,!(`<-(B=_H^=[__TB-="0<08G%2(GO,<#H
MU_K__TB%P$F)Q`^$"P$``$B)Q^C3WO__1(GI,=)(.<@/@\T```!$BV0D'`^V
M10`\/0^$I`$``(3`#X2<`0``2(GHZPL/'X``````A-)T#$B#P`$/MA"`^CUU
M\"GH2(L-UX,@`$&-?`4"3HTDX>@)X/__2(7`28D$)`^$8P$``(M4)!Q(BP6Q
M@R``2(L$T`^V50"$TH@0="J`^CUT)4B#Q0'K#0\?A```````@/H]=!(/ME4`
M2(/``4B#Q0&$TH@0=>G&`#TQT@\?0``/M@P3B$P0`4B#P@&$R77P,<!(@\0H
M6UU!7$%=05Y!7\,/'X``````#[8$$T&(!!1(@\(!A,!TV`^V!!-!B`042(/"
M`83`=>#KQF8/'T0``$R+/1F#(`!%,>2^$````$F#/P!T)4R)^`\?A```````
M2(/`"$&#Q`%(@S@`=?)!C70D`DAC]DC!Y@.+/3"#(`"%_W0T3(G_Z)3?__](
MA<!)B<9(B07'@B``=&Q)8\Q)QT3."`````!$B60D'.F?_O__#Q^``````$B)
M]\<%ZX(@``$```#HUM[__TB%P$F)QG0U26/,3(G^2(G'2(T4S0````!(B4PD
M".A3W___3(DU;((@`$B+3"0(ZZ,/'T0``#'`Z7O^__^X_____^GQ_O__9F9F
M9F9F+@\?A```````2(E<).A,B60D^$B)^TB);"3P2('L*!```$F)]+K_#P``
M2(GFO^)90`!D2(L$)2@```!(B80D"!```#'`Z`_<__^%P`^.?P```(U0_TAC
MZH`\+`!T:TACZ$B)ZKXO````2(GGZ'C=__](A<!T6XL]O8$@`.CXW?__2(GI
M2(GB2(G>2(G'Z/?>__](BX0D"!```&1(,P0E*````'5'2(N<)!`0``!(BZPD
M&!```$R+I"0@$```2('$*!```,,/'T``A=)UE`\?0`"+/6*!(`#HG=W__TR)
MXDB)WDB)Q^A?W/__ZZ;H&-S__P\?A```````2(/L"(L]-H$@`.AQW?__N?%9
M0`"Z\!U``+[[64``2(G'2(/$".F&W?__9@\?1```2(/L"(L]!H$@`.A!W?__
M2(G'Z+G___^+/?.`(`#H+MW__T&XNUM``$4QR;HP5$``3(G!OA=:0`!(B<=(
M@\0(Z8S=__]F9F8N#Q^$``````!54S';2('L*"```&1(BP0E*````$B)A"08
M(```,<#HW=K__[GM64``B<*^+%I``#'`2(GGZ!?>__^%P'A(2(VT)!`0``"Z
M`!```$B)Y^B.VO__A<")Q7@MC7T!2&/_Z*W<__](A<!(B<-T&DAC[4B-M"00
M$```2(G'2(GJZ!_<___&!"L`2(N4)!@@``!D2#,4)2@```!(B=AU"DB!Q"@@
M``!;7</HYMK__V8/'T0``.E+____9F8N#Q^$``````!!54F)]4%454B)_;\Z
M6D``4TB![!@0``!D2(L$)2@```!(B80D"!```#'`Z%#W__^^+P```$B)[TB)
MP^BPVO__2(7`=#=(B>Z_0UI``#'`Z$S[__](BY0D"!```&1(,Q0E*````$B)
MZ`^%-0$``$B!Q!@0``!;74%<05W#2(GOZ#S:__],B>^^4%I``$&)Q.BLW/__
M28G%9@\?A```````387M=*!!@'T``+@X6D``3`]$Z$B%VW033(GN2(G?Z"W;
M__^%P`^$E@```$R)[^CMV?__2&/008!\%?\O=1E)C505_P\?1```Q@(`2(/J
M`8/H`8`Z+W3Q08U$!`$]_P\```^//O___TF)Z+E26D``3(GJOG%;0`!(B><Q
MP.AOW/__BSW9?B``Z!3;__](C9"8````2(GFOP$```#H(-G__X7`=1V+/;9^
M(`#H\=K__XN`L````"4`\```/0"```!T%+Y06D``,?_HT]O__TF)Q>DK____
MO@$```!(B>?HKMO__X7`==M(B>:_0UI``.@-^O__2(GGZ/79__](B<7IL?[_
M_^@HV?__#Q^$```````/M@](B?B$R7092(U7`6:0@/DO2`]$PDB#P@$/MDK_
MA,EU[?/#9F8N#Q^$``````!(A?]32(G[=">`/P!T(NC-V/__2(U4`_](.=-R
M#.L_D$B#Z@%(.=IT=X`Z+W3RZR6_`@```.@VVO__2(7`=`5FQP`N`%O#9BX/
M'X0``````(`Z+W0)2(/J`4@YTW+R2#G:=#T/'T0``$B#Z@%(.=-S!8`Z+W3R
M2"G:,<!(C4H"2('Y`!```'>\2(G>2(/"`;\@Q&``Z'?7__^X(,1@`%O#@#HO
M=`M;OU):0`#I`-G__[\"````Z+;9__](B<(QP$B%TG2`9L<"+@!(B=!;PV:0
M2(/L.+]46D``9$B+!"4H````2(E$)"@QP$B+!5@5``!(B00D2(L%514``$B)
M1"0(2(L%414``$B)1"002(L%314``$B)1"08#[<%214``&:)1"0@,<#HE?3_
M_S'`OUU:0`#HB?3__S'`OV5:0`#H??3__S'`OVY:0`#H<?3__S'`OW5:0`#H
M9?3__S'`OX5:0`#H6?3__S'`OSI:0`#H3?3__S'`OY%:0`#H0?3__S'`OYM:
M0`#H-?3__S'`OZ5:0`#H*?3__S'`OT-:0`#H'?3__S'`OZ]:0`#H$?3__S'`
MO[A:0`#H!?3__S'`O\-:0`#HV?/__TB%P'0/2(G&OYM:0``QP.CE]___,<"_
MU%I``.BY\___2(7`=`](B<:_YEI``#'`Z,7W__\QP+_Q6D``Z)GS__](A<!T
M/$B)QK\Z6D``,<#HI??__S'`OAU;0`"_=5I``.B4]___2(M$)"AD2#,$)2@`
M``!U6DB#Q#C##Q^``````#'`OP%;0`#H3//__TB%P'072(G&OY%:0``QP.A8
M]___Z[%F#Q]$``!(C70D$;\26T``N0H```#SIG682(UT)!N_D5I``#'`Z"SW
M___KA>A5UO__#Q]$``!(@^P(BP66'R``@_C_=`E(@\0(PP\?0``QP+^16D``
MZ-SR__](B<(QP$B%TG0/#[82A-)T"#'`@/HP#Y7`B05='R``2(/$",,/'X0`
M`````$B#[`CH!];__XG'Z+#5__](A<!T"TB+`$B#Q`C##Q\`,<#K]&9F9BX/
M'X0``````$%6055!5$F)_%53NRE;0`!(@^Q`2,<$)"E;0`!(QT0D"!];0`!(
MC6PD"$C'1"00+%M``$C'1"08(EM``$C'1"0@)UM``$C'1"0H.5M``$C'1"0P
M`````.LA#Q^``````$B)Q^AHV/__2(7`=%-(@\4(2(M=^$B%VW0Q,<!(B=_H
M_/'__TB%P$F)QDR)YG0%@#@`=<Q(B=\QP.@"]O__2(/%"$B+7?A(A=MUSTB#
MQ$!;74%<05U!7L,/'X0``````$R)Y^CXU/__3(GW28G%Z.W4__])C7P%`NAS
MUO__38GP28G%2(G'N5!:0`!,B>*^<5M``#'`Z);7__],B>Y(B=\QP.B9]?__
MZY4/'X``````05=!5D%505154TB)^[\Z6D``2('L>($``&1(BP0E*````$B)
MA"1H@0``,<!(QT0D8%!;0`!(QT0D:#A:0`!(QT0D<`````!(QT0D,.9:0`!(
MQT0D.-]:0`!(QT0D0%5;0`!(QT0D2/Q:0`!(QT0D4%U;0`!(QT0D6`````!(
MQX0D@````$1;0`!(QX0DB````&%;0`!(QX0DD`````````#HRO#__TB%P'0)
M@#@`#X6\`P``,<#H!?[__TB%P$F)Q@^$RP,``$$/MBY`A.UT+.C[UO__3(GR
M#Q^$``````!(BPA(#[[M]@1I"'4#Q@)?2(/"`0^V*D"$[77D3(UD)#B_YEI`
M`.L6#Q^$``````!)@\0(28M\)/A(A?]T,C'`Z$OP__](A<!(B<5TXX`X`'3>
M2(G'Z*;S__^%P'322(GOZ#K4__](A<!)B<5U76:02(ML)&!%,>U(A>UT3H!]
M``!!O`$```!U)NM`#Q]$``!)8\1(BVS$8$B%[0^$+P$``$&#Q`&`?0``#X0A
M`0``2(GOZ$GS__^%P'352(GOZ-W3__](A<!)B<5TQ4R)[^C]TO__3(GW2(G%
MZ/+2__^-K`4$!```2&/M2(GOZ'#4__]-B?%(B<=)B<1!N&I;0`"Y4EI``$R)
MZKYO6T``,<#HC=7__[[``0``3(GGZ`#2__^#^/]T<XL]Y7<@`.@@U/__2(V0
MF````$R)YK\!````Z$S5__^%P`^$E````$B+$TB+/?)W(`!,B>&^,%Q``#'`
M,>WHN=/__TB+E"1H@0``9$@S%"4H````2(GH#X47"```2('$>($``%M=05Q!
M74%>05_##Q]$``#H0]'__T2+`$&#^!$/A'O___](BQ-(BSV4=R``3(GAOO!;
M0``QP#'MZ%O3___KH&8/'X0``````$4Q[>GS_O__#Q^$``````"+/2IW(`#H
M9=/__XN`L````"4`\```/0!````/A4O___^+/0EW(`#H1-/__T2+J+0```#H
MV-'__T$YQ0^%*____XL]Z78@`.@DT___BX"P````)?\!```]P`$```^%"O__
M_TB)[^@6T___OR);0`!(B<4QP.@W[O__2(7`2(G'#X2?`0``Z#;2__](BSM(
MB<;HF_;__TB%P$F)Q0^$@P$``$R)[^A'T?__@_@#?C)(8]"_>%M``+D%````
M28UT%?SSIG4<@_@$#X3V!0``@^@$2)A!@'P%_R\/A.4%``!FD#'`Z,GZ__^%
MP'45,?9,B>_H&]/__X7`08G&#X4L`0``OAU;0`"_D5I``#'`Z+_Q___H6M#_
M_T&YNUM``$&)P+E26D``3(GBOI9;0`!(B>\QP#';Z(C3___K/68/'T0``.B[
MS___@S@1=3^#PP'H'M#__T&)V4&)P+E26D``3(GBOJ1;0`!(B>\QP$C'!"2[
M6T``Z$G3__^^P`$``$B)[^B\S___@_C_=+=,B>?H7\___TB)[K\Z6D``,<#H
M,/'__TB)[^B(^O__Z=K]__\/'P!(B<=(B40D$.AS^O__2(M$)!!(B<?H]M#_
M_TB)Q>FU_?__O0$```"_1%M``.L59I!(8\6#Q0%(B[S$@````$B%_W0F,<#H
MMNS__TB%P'3A@#@`=-Q(B<?HM-#__TB%P$F)QG3,Z>[[__]!ODE;0`#I&/S_
M_TR+*^EU_O__N@(```!(Q\;N____B<?HH=+__TB-M"2@````N@8```!$B??H
MG-#__X"\)*``````=0Z`O"2A````0P^$TP0``#'2,?9$B??H:-+__TB-G"38
M@```0;B)J\WO0;G^W+J80;KPX=+#2,>$)*"````!(T5G3(F$)*B```!,B8PD
ML(```$C'A"2X@```=E0R$$R)E"3`@```2,>$),B`````````2,>$)-"`````
M````QX0D&($````````/'P!(C;0DH````+H`@```1(GWZ///__^%P$&)Q0^.
M<0$``$B+C"3(@```26/%B[PD&($``$R-O"2@````C13!2#G*2(F4),B````/
MDL%(P>@=#[;)2`&,)-"```!(`80DT(```(7_=&)!OT````!(C;0DH````$$I
M_TAC_T4Y_44/3OU(`=])8]=(B50D&.B7S___BX0D&($``$0!^(/X0(F$)!B!
M```/A57___](C;PDH(```$4I_4R-O"2@````3`-\)!CH<-3__T&#_3\/CJ0`
M``!!C47`P>@&B<*)1"0D2(G02(E4)"A(P>`&28U$!T!(B40D&$R)^$B+$$B-
MO"2@@```2(D32(M0"$B)4PA(BU`02(E3$$B+4!A(B5,82(M0($B)4R!(BU`H
M2(E3*$B+4#!(B5,P2(M0.$B#P$!(B5,X2(E$)!#H[-/__TB+1"002#M$)!AU
MH$B+1"0H2(/``4C!X`9)`<>+1"0D]]C!X`9%C6P%P$ECU4R)_DB)W^BDSO__
M1(FL)!B!``#I;_[__T2)]^C_S?__2(N<),B```!,BZPDT(```$B)V$C!Z`.#
MX#^-2`%(8]#&A!38@```@(/Y.`^/2@(``+HW````2&/),?8IPDB-O`S8@```
M2&/2Z(+-__],B>A(C;PDH(```(B<)!>!``!(P>@81(BL)!.!``"(A"00@0``
M3(GH2,'H$(B$)!&!``!,B>A(P>@(B(0D$H$``$B)V$C!Z!B(A"04@0``2(G8
M2,'H$(B$)!6!``!(B=@QVTC!Z`B(A"06@0``Z.#2__](BX0DH(```$B)P8B$
M)%.!``!(P>D8B<J(C"10@0``2(G!2,'I$(B,)%&!``!(B<%(BX0DJ(```$C!
MZ0B(C"12@0``2(G!B(0D5X$``$C!Z1B(C"14@0``2(G!2,'I$(B,)%6!``!(
MB<%(BX0DL(```$C!Z0B(C"16@0``2(G!B(0D6X$``$C!Z1B(C"18@0``2(G!
M2,'I$(B,)%F!``!(B<%(BX0DN(```$C!Z0B(C"1:@0``2(G!B(0D7X$``$C!
MZ1B(C"1<@0``2(G!2,'I$(B,)%V!``!(B<%(BX0DP(```$C!Z0B(C"1>@0``
M2(G!B(0D8X$``$C!Z1B(C"1@@0``2(G!2,'I$(B,)&&!``!(B<%(P>D(B(PD
M8H$``.D,````#Q]```^VE!Q0@0``2(V\7""!```QP`^VTKZ16T``2(/#`>@U
MSO__2(/[%'773(V$)""!``#&A"1(@0```$&YNUM``+E26D``3(GBOH);0`!(
MB>\QP.@"SO__Z<;Z__](BUL(2(7;#X00^O__2(G?Z!C+__](@_@##X;^^?__
M2(UT`_R_?5M``+D%````\Z9,#T3KZ>3Y__](8\FZ/P```#'V2(V\#-B````I
MPDACTN@XR___2(V\)*"```#H^]#__TB-E"38@```N0<````QP$B)U_-(J^F/
M_?__@+PDH@```$$/A1_[__^`O"2C````0P^%$?O__X"\)*0```!(#X4#^___
M@+PDI0```$4/A?7Z__^Z`@```$C'QL;___]$B??H5<W__TB-M"2@````NBD`
M``!$B??H4,O__T&YNUM``$R-A"2@````Z?3^__\/'T0``.A#RO__#Q\`055!
M5%532(/L"(L]8&\@`.B;R___OW5:0`#&@,4$```!,<#HR.;__TB%P'0)@#@Q
M#X2*`@``,<#HX_'__XL]+6\@`.AHR___N0L```"Z`0```+ZU6T``2(G'Z!'+
M__](A<`/A+D```!(BT`0,=M,BV`HBP6`?R``@_@!#XZ5````O0@```#K-`\?
MA```````28MU$$B+!55_(`!(BSPHZ+S*__^%P'5H@\,!BP5'?R``2(/%"(U3
M`3G0?EJ+/:YN(`#HZ<K__S')B=I,B>9(B<?HJLO__TB%P'0U3(LH0?9%#01U
MJXL]A6X@`.C`RO__3(GNN0(````QTDB)Q^B>R?__2(G&ZXUF#Q^$``````"+
M!>)^(`"-4/\YV@^$-P$``(L]26X@`.B$RO__N00```"Z`0```+ZZ6T``2(G'
MZ"W*__](A<!(B<-T,TB+0!"+/1MN(`!(BRCH4\K__[J\6T``2(G'2(GNZ!/)
M__](BT,02(L8]D,.0`^%(@$``(L][&T@`.@GRO__N00```"Z`0```+[!6D``
M2(G'Z-#)__](A<!(B<-T.#'`OT-:0`#H/.7__TB%P$F)Q`^$B`$``$B+0Q"+
M/:9M(`!(BRCHWLG__TR)XDB)QTB)[NB@R/__BSV*;2``Z,7)__^+/7]M(`#&
M@,4$````Z+/)__^_.EI``$C'@$@'````````,<#HW.3__TB%P$B)!>)](``/
MA+0```"^P`$``$B)Q^A/Q___@_@1=!"%P'0,@_C_#Q\`#X6"`0``2(/$"%M=
M05Q!7<,/'X``````@_@!#X[`_O__NP$```!F+@\?A```````BSWZ;"``@\,!
MZ#+)__],B>9(B<?H%\?__SD=:7T@`'_?Z8O^__]F+@\?A```````BSW*;"``
MZ`7)__](B=Y(B<?H6LG__^G#_O__#Q]$``"`>`$`#X1S_?__9@\?1```Z6']
M__\/'P!(BST1?2``Z)SR__](A<!(B042?2``#X3*````2(M#$$B++?%\(`!,
MBR!!]D0D#01T:DF+?"002(GNZ+G)__^)Q4B+0Q!(BQCV0PT$='-(BU,02(L%
MOWP@`(GIO[!<0`!(BS`QP.B.R/__9@\?1```2(L%H7P@`(L]&VP@`$R+($B+
M0Q!(BRCH3,C__TR)YDB)[^C1Z?__Z6S^__^+/?9K(`#H,<C__[D"````2(G'
M,=),B>;H#\?__TB)Q^EV____BSW1:R``Z`S(__\QTKD"````2(G>2(G'Z.K&
M__](B<+I;/___[^(7$``Z`C(__^)P4B+!1]\(`!(BQ4H?"``O]A<0`!(BS`Q
MP.CIQ___9@\?A```````54B)_5-(@^P(Z%+M__\/MA!(B<.$TG0;2(U``0\?
M0`"`^B](#T382(/``0^V4/^$TG7M,<#HQN___X7`=!U(A>UT&(!]``!T$KYJ
M6T``2(G?Z/K(__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWI@.3__TB#[`B+/09K
M(`#H0<?__[[_____2(G'Z&3&__^+/>YJ(`#H*<?__S'2OJ`[0`!(B<=(@\0(
MZ9;(__^0D)"0D)!(C071#B``2(7`=`Q(BPW%#B``Z3C&__\QR>OWD)"0D//#
M9F9F9F8N#Q^$``````!(B6PDV$R)9"3@2(TM.PH@`$R-)30*(`!,B6PDZ$R)
M="3P3(E\)/A(B5PDT$B#[#A,*>5!B?U)B?9(P?T#28G7Z//#__](A>UT'#';
M#Q]``$R)^DR)]D2)[T'_%-Q(@\,!2#GK<NI(BUPD"$B+;"003(MD)!A,BVPD
M($R+="0H3(M\)#!(@\0XPY"0D)"0D)!52(GE4TB#[`A(BP6P"2``2(/X_W09
MNU!C8``/'T0``$B#ZPC_T$B+`TB#^/]U\4B#Q`A;7<.0D$B#[`CH'\K__TB#
MQ`C#```!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`<&5R;'AS:2YC`$1Y;F%,
M;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O
M<')O8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,
M24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!
M4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`%!!4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%-(
M3$E"7U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-
M10!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X
M`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``M
M90`M+0``7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````````````````````
M`````,!#`1L#._0````=````(,#__Q`!``!@Q/__F`4``&#'__\X`0``(-W_
M_X@!``#PW?__Z`$``!#>__\``@``<-[__R`"``#@W___4`(``&#A__]X`@``
M$.+__Y@"``!`Y/__Z`(``##E__\0`P``8.7__R@#``"PY?__0`,``&#F__]P
M`P``<.;__X@#```@Z/__R`,``%#H___@`P``(.G__Q`$``#PZO__,`0``$#K
M__]0!```<.O__W`$``"`[/__N`0```#W__\(!0``\/K__T@%``!@^___@`4`
M`*#[___`!0``P/O__]@%``#0^___\`4````````4``````````%Z4@`!>!`!
M&PP'")`!```D````'`````B___]`!`````X01@X82@\+=PB``#\:.RHS)"(`
M````3````$0````@QO__NA4```!"#A"/`D@.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P='#L`$`Y@5#CA!#C!!#BA"#B!"#AA"#A!"#@@```````!<````E```
M`)#;___&`````$(.$(\"10X8C@-"#B"-!$4.*(P%00XPA@9!#CB#!T0.0`)X
M"@XX00XP00XH0@X@0@X80@X00@X(2@M;#CA!#C!!#BA"#B!"#AA"#A!"#@@4
M````]`````#<__\5`````$0.(%`."``<````#`$```C<__]8`````$$.$(,"
M1PX@`DX.$$$.""P````L`0``2-S__V8!````00X0A@)!#AB#`T0.(`-=`0X8
M00X000X(`````````"0```!<`0``B-W__W(!````38,&A@56#L`!C@*-`XP$
M>0H."$0+```<````A`$``.#>__^A`````$V&`H,#1`X@=0H."$H+`$P```"D
M`0``<-___R$"````0@X0CP)$#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@
M`P`!"@XX00XP00XH0@X@0@X80@X00@X(2`L`````)````/0!``!0X?__Z```
M``!-C`*#!$P.L""&`P*B"@X(10L``````!0````<`@``&.+__RH`````1`X0
M80X(`!0````T`@``,.+__T0`````1`X0>PX(`"P```!,`@``:.+__ZH`````
M00X0A@)!#AB#`TD.P$`"EPH.&$$.$$$."$$+`````!0```!\`@``Z.+__P4`
M`````````````#P```"4`@``X.+__Z@!````0@X0C0)%#AB,`T$.((8$20XH
M@P5'#L`@`ET*#BA!#B!!#AA"#A!"#@A!"P`````4````U`(``%#D__\E````
M```````````L````[`(``&CD___.`````$0.$(,"`D$*#@A+"P)/"@X(00M&
M"@X(2@M=#@@````<````'`,```CE___+`0```$0.0`-L`0H."$@+`````!P`
M```\`P``N.;__T@`````1`X03PH."$4+;PX(````'````%P#``#HYO__)```
M``!$#A!8"@X(1`L```````!$````?`,``/CF__\)`0```$(.$(X"0@X8C0-"
M#B",!$0.*(8%00XP@P9)#G`"FPH.,$$.*$$.($(.&$(.$$(."$D+``````!,
M````Q`,``,#G__]]"@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T\.L(,"`T\""@XX00XP00XH0@X@0@X80@X00@X(1@L``#P````4!```\/'_
M_^<#````0@X0C0)"#AB,`T$.((8$00XH@P5$#C`#0`(*#BA!#B!!#AA"#A!"
M#@A("P`````T````5`0``*#U__]P`````$$.$(8"1`X8@P-$#B`"5@H.&$$.
M$$$."$$+1`X81`X000X(`````!0```",!```V/7__SH`````1`X0<0X(`"0`
M``"D!```P+[__PX"````00X0@P)$#C`#CP$*#A!##@A!"P`````4````S`0`
M`-CU__\<```````````````4````Y`0``.#U__\"```````````````D````
M_`0``-CU__^)`````%&,!88&7PY`1H,'CP*.`XT$``````````````````#_
M_________P``````````__________\``````````````````````0``````
M```!``````````$`````````SP$````````!`````````-H!`````````0``
M``````#D`0````````$`````````,P(````````!`````````&\#````````
M#``````````X'4````````T`````````R%E````````$`````````&`"0```
M````]?[_;P````"(!4````````4`````````.!!````````&`````````)`&
M0```````"@````````#E!`````````L`````````&``````````5````````
M`````````````P````````!P96````````(`````````2`8````````4````
M``````<`````````%P````````#P%D````````<`````````8!9````````(
M`````````)``````````"0`````````8`````````/[__V\`````\!5`````
M``#___]O``````(`````````\/__;P`````>%4``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````>&-@````````````````````````````9AU```````!V'4```````(8=
M0```````EAU```````"F'4```````+8=0```````QAU```````#6'4``````
M`.8=0```````]AU````````&'D```````!8>0```````)AY````````V'D``
M`````$8>0```````5AY```````!F'D```````'8>0```````AAY```````"6
M'D```````*8>0```````MAY```````#&'D```````-8>0```````YAY`````
M``#V'D````````8?0```````%A]````````F'T```````#8?0```````1A]`
M``````!6'T```````&8?0```````=A]```````"&'T```````)8?0```````
MIA]```````"V'T```````,8?0```````UA]```````#F'T```````/8?0```
M````!B!````````6($```````"8@0```````-B!```````!&($```````%8@
M0```````9B!```````!V($```````(8@0```````EB!```````"F($``````
M`+8@0```````QB!```````#6($```````.8@0```````]B!````````&(4``
M`````!8A0```````)B%````````V(4```````$8A0```````5B%```````!F
M(4```````'8A0```````AB%`````````````````````````````````````
M`````````````/____\`````````````````````````````````````(R$O
M=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@
M;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*
M(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@
M("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A
M(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T
M;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN
M:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C
M('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W
M('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE
M8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG
M<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R
M92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C
M($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R
M96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N
M:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@
M("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@
M(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R
M;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@
M("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D
M8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP
M+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@
M($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME
M9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R
M86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S
M96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@
M7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ
M,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ
M,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]
M?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[
M"B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D
M9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@
M("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*
M("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@
M("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@
M("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B
M=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@
M("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T[
M"B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@
M("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@
M("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D
M;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N
M.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D
M(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R
M960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E
M='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@
M24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@
M("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@
M("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A
M8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z
M"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT
M<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I
M;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@
M("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R
M"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P
M87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H
M92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM
M<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@
M=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN
M9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P
M('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S
M:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@
M*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@
M97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG
M*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@
M("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@
M("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G
M*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@
M("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@
M("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@
M("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@
M("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I
M<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@
M<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@
M>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M
M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E
M;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R
M)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@
M("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@
M(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^
M(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP
M=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@
M("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I
M.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H
M*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@
M("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@
M("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*
M("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@
M("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@
M("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@
M;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E
M7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@
M("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@
M("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@
M("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@
M("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E
M9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES
M=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U
M=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@
M=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@
M4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S
M=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N
M("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N
M*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[
M"B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@
M("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@
M("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@
M("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@
M("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F
M*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)
M3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@
M("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@
M("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C
M($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*
M("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@
M("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@
M("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L
M;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI
M=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE
M(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE
M(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@
M("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@
M("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI
M"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@
M("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@
M("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA
M:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC
M('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A
M=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI
M8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E
M<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*
M("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@
M<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I
M8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E
M(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A
M"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@
M9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@
M("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*
M("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@
M("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@
M("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU
M."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@
M("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]
M"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@
M("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY
M("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*
M"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M
M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I
M;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E
M9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D
M92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE
M(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA
M;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N
M86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@
M("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@
M("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D
M*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@
M("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@
M("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@
M("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E
M("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@
M("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I
M9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO
M9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`
M7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N
M9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T
M:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@
M+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*
M7U]%3D1?7PH`````1T-#.B`H1&5B:6%N(#0N-BXR+34I(#0N-BXR`$=#0SH@
M*$1E8FEA;B`T+C0N-BTQ,"D@-"XT+C8``"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M
M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````
M````````````````````````````````````````````````````````````
M``````````````````````L````!`````@```````````D`````````"````
M````'`````````````````````$````````````````````3````!P````(`
M````````'`)````````<`@```````"`````````````````````$````````
M````````````(0````<````"`````````#P"0```````/`(````````D````
M````````````````!````````````````````#@````%`````@````````!@
M`D```````&`"````````*`,````````&``````````@`````````!```````
M```T````]O__;P(`````````B`5```````"(!0````````0!````````!@``
M```````(````````````````````/@````L````"`````````)`&0```````
MD`8```````"H"0````````<````!````"``````````8`````````$8````#
M`````@`````````X$$```````#@0````````Y00```````````````````$`
M``````````````````!.````____;P(`````````'A5````````>%0``````
M`,X`````````!@`````````"``````````(`````````6P```/[__V\"````
M`````/`50```````\!4```````!P``````````<````"````"```````````
M`````````&H````$`````@````````!@%D```````&`6````````D```````
M```&``````````@`````````&`````````!T````!`````(`````````\!9`
M``````#P%@```````$@&````````!@````T````(`````````!@`````````
M?@````$````&`````````#@=0```````.!T````````8````````````````
M````!````````````````````'D````!````!@````````!0'4```````%`=
M````````0`0``````````````````!``````````$`````````"$`````0``
M``8`````````D"%```````"0(0```````#@X```````````````````0````
M````````````````B@````$````&`````````,A90```````R%D````````.
M````````````````````!````````````````````)`````!`````@``````
M``#864```````-A9````````6`,```````````````````@`````````````
M``````"8`````0````(`````````,%U````````P70```````/0`````````
M```````````$````````````````````I@````$````"`````````"A>0```
M````*%X````````D!0``````````````````"````````````````````+``
M```!`````P````````!08V```````%!C````````$```````````````````
M``@```````````````````"W`````0````,`````````8&-@``````!@8P``
M`````!`````````````````````(````````````````````O@````$````#
M`````````'!C8```````<&,````````(````````````````````"```````
M`````````````,,````&`````P````````!X8V```````'AC````````\`$`
M```````'``````````@`````````$`````````#,`````0````,`````````
M:&5@``````!H90````````@````````````````````(``````````@`````
M````T0````$````#`````````'!E8```````<&4````````P`@``````````
M````````"``````````(`````````-H````!`````P````````"@9V``````
M`*!G````````Y%L``````````````````"````````````````````#@````
M"`````,`````````H,-@``````"$PP```````*`0```````````````````@
M````````````````````Y0````$````P````````````````````A,,`````
M```Y`````````````````````0`````````!``````````$````#````````
M`````````````````+W#````````[@````````````````````$`````````
(````````````
